#ifndef NT2_DSL_INCLUDE_FUNCTIONS_RUN_HPP_INCLUDED
#define NT2_DSL_INCLUDE_FUNCTIONS_RUN_HPP_INCLUDED

#include <nt2/dsl/functions/run.hpp>
#include <boost/simd/dsl/functions/run.hpp>
#include <nt2/dsl/functions/container/run.hpp>
#include <nt2/dsl/functions/cumulative/run.hpp>
#include <nt2/dsl/functions/elementwise/run.hpp>
#include <nt2/dsl/functions/generative/run.hpp>
#include <nt2/dsl/functions/reduction/run.hpp>
#include <nt2/dsl/functions/reshaping/run.hpp>
#include <boost/simd/dsl/functions/generic/run.hpp>

#endif
